@@ -4,24 +4,21 @@
 # Copyright 2021 Peter Dunne
 """3D Magnet classes
 
-This private module implements the `Prism`, `Cube`, `Cylinder`, and `Sphere`
-3D magnet classes. The parent class `Magnet3D` implements the location and orientation
-methods, i.e. magnet center and quaternion methods for rotating the magnet with respect
-to each principal axis.
+This private module implements the `Prism`, `Cube`, `Cylinder`, and `Sphere` 3D
+magnet classes. The parent class `Magnet3D` implements the location and
+orientation methods, i.e. magnet center and quaternion methods for rotating the
+magnet with respect to each principal axis.
 
-TODO:
-    * Update __str__ and __repr__ methods to show orientation and magnetisation
+TODO: Update __str__ and __repr__ methods to show orientation and magnetisation
 """
+from math import fabs, sqrt
+
 import numpy as _np
-from ._magnet_base import Magnet
+from numba import float64, vectorize
+
 from ..utils._quaternion import Quaternion
 from ..utils.global_const import MAG_TOL, PI
-
-from numba import vectorize, float64
-from math import sqrt, fabs
-
-
-__all__ = ["Magnet3D", "Prism", "Cube", "Cylinder", "Sphere"]
+from ._magnet_base import Magnet
 
 
 class Magnet3D(Magnet):
@@ -45,9 +42,12 @@ class Magnet3D(Magnet):
         Kwargs:
             center (ndarray): Magnet center. Defaults to (0.0, 0.0, 0.0)
             mask_magnet (bool): Flag to mask magnet or not in plots
-            alpha (float): Magnet Orientation angle about z (degrees). Defaults to 0.0
-            beta (float): Magnet Orientation angle about y (degrees). Defaults to 0.0
-            gamma (float): Magnet Orientation angle about x (degrees). Defaults to 0.0
+            alpha (float): Magnet Orientation angle about z (degrees).
+            Defaults to 0.0
+            beta (float): Magnet Orientation angle about y (degrees).
+            Defaults to 0.0
+            gamma (float): Magnet Orientation angle about x (degrees).
+            Defaults to 0.0
         """
         super().__init__()
 
@@ -135,9 +135,12 @@ class Magnet3D(Magnet):
 
     def get_field(self, x, y, z):
         """Calculates the magnetic field at point(s) x,y,z due to a 3D magnet
-        The calculations are always performed in local coordinates with the centre of the magnet at origin and z magnetisation pointing along the local z' axis.
+        The calculations are always performed in local coordinates with the
+        centre of the magnet at origin and z magnetisation pointing along the
+        local z' axis.
 
-        The rotations and translations are performed first, and the internal field calculation functions are called.
+        The rotations and translations are performed first, and the internal
+        field calculation functions are called.
 
         Args:
             x (ndarray): x co-ordinates
@@ -147,7 +150,7 @@ class Magnet3D(Magnet):
         Returns:
             tuple: Bx(ndarray), By(ndarray), Bz(ndarray) field vector
         """
-        from ..utils._routines3D import _tile_arrays, _apply_mask
+        from ..utils._routines3D import _apply_mask, _tile_arrays
 
         # If any rotation angle is set, transform the data
         if _np.any(
@@ -209,7 +212,7 @@ class Magnet3D(Magnet):
         """
         pass
 
-    def _get_field_internal(x, y, z):
+    def _get_field_internal(self, x, y, z):
         """Internal magnetic field calculation method. This should be defined
         for each magnet type.
 
@@ -289,6 +292,7 @@ class Prism(Magnet3D):
         self.theta = kwargs.pop("phi", 0.0)
         self.theta_rad = _np.deg2rad(self.theta)
 
+        # Generate components of magnetisation
         self.Jx = _np.around(
             Jr * _np.cos(self.phi_rad) * _np.sin(self.theta_rad), decimals=6
         )
@@ -543,7 +547,7 @@ class Prism(Magnet3D):
         return data
 
     def _calcB_prism_x(self, x, y, z):
-        """Calculates agnetic field vector due to magnet magnetised in x
+        """Calculates magnetic field vector due to magnet magnetised in x
 
         Args:
             x (ndarray): x-coordinates
@@ -557,7 +561,7 @@ class Prism(Magnet3D):
         a = self.a
         b = self.b
         c = self.c
-        Jr = self.Jr
+        Jr = self.Jx
 
         Bx = self._calcBx_prism_x(a, b, c, Jr, x, y, z)
         By = self._calcBy_prism_x(a, b, c, Jr, x, y, z)
@@ -578,7 +582,7 @@ class Prism(Magnet3D):
         a = self.a
         b = self.b
         c = self.c
-        Jr = self.Jr
+        Jr = self.Jz
 
         Bx = self._calcBz_prism_x(-c, b, a, Jr, -z, y, x)
         By = self._calcBy_prism_x(-c, b, a, Jr, -z, y, x)
@@ -599,7 +603,7 @@ class Prism(Magnet3D):
         a = self.a
         b = self.b
         c = self.c
-        Jr = self.Jr
+        Jr = self.Jy
 
         Bx = self._calcBy_prism_x(-b, a, c, Jr, -y, x, z)
         By = -1 * self._calcBx_prism_x(-b, a, c, Jr, -y, x, z)
