@@ -10,8 +10,16 @@ This module imports the classes and functions in the private modules to create a
 - 3D surface and volume plots are rendered using plotly.
 
 """
-from ._plot1D import *
-from ._plot2D import *
-from ._plotly3D import *
+from ._plot1D import plot_1D_field
+from ._plot2D import plot_2D_contour, plot_2D_line, plot_3D_contour, plot_sub_contour_3D
+from ._plotly3D import (
+    plot_magnet,
+    slice_plot,
+    slice_quickplot,
+    volume_plot,
+    volume_quickplot,
+)
 
 # from ._plotly2D import *
+
+__all__ = [plot_1D_field, plot_2D_line, plot_2D_contour, plot_3D_contour, plot_sub_contour_3D, plot_magnet, slice_plot, slice_quickplot, volume_plot, volume_quickplot]
