@@ -5,24 +5,23 @@
 """Plotting routines
 
 This module contains all functions needed to plot lines and contours for 2D
-magnetic sources, and 
+magnetic sources, and
 
 """
 
-__all__ = ["plot_2D_line", "plot_2D_contour", "plot_3D_contour", "plot_sub_contour_3D"]
-
-from .. import magnets as _mag
-from ..utils._conversions import get_unit_value_meter, get_unit_value_tesla
-from ..utils._vector_structs import Field2, Point_Array2
-
-import numpy as _np
-import matplotlib.pyplot as _plt
 import matplotlib.cm as _cm
-from matplotlib.patches import Rectangle as _Rect
-from matplotlib.patches import Circle as _Circ
+import matplotlib.pyplot as _plt
+import numpy as _np
 from matplotlib.patches import Arrow as _Arrow
+from matplotlib.patches import Circle as _Circ
+from matplotlib.patches import Rectangle as _Rect
 from matplotlib.transforms import Affine2D
 
+from ..utils import Field2, Point_Array2
+
+# from ..utils._conversions import get_unit_value_meter, get_unit_value_tesla
+# from .. import magnets as _mag
+
 
 class patch(object):
     """Encodes magnet dimensions for drawing on plots"""
@@ -116,7 +115,7 @@ def plot_2D_line(point_array, field, **kwargs):
 
     xlab = kwargs.pop("xlab", f"x ({point_array.unit})")
     ylab = kwargs.pop("ylab", f"B ({field.unit})")
-    axis_scale = kwargs.pop("axis_scale", "equal")
+    # axis_scale = kwargs.pop("axis_scale", "equal")
 
     SAVE = kwargs.pop("save_fig", False)
 
@@ -153,7 +152,7 @@ def plot_2D_contour(point_array, field, **kwargs):
         field_component (str): Defaults to 'n'.
         plot_type (str): Draw `contour` or `streamplot`. Defaults to 'contour'
         cmap (str): Colormap. Defaults to `viridis`
-        vector_plot (bool): Draw vectors as arrows. Defaults to False.
+        num_arrows (int or None): Number of arrows per axis. Defaults to None.
         vector_color (str): Arrow color. Defaults to 'w'
         cmin (float): Color scale minimum. Defaults to 0.0
         cmax (float): Color scale minimum. Defaults to twice the mean field
@@ -166,6 +165,7 @@ def plot_2D_contour(point_array, field, **kwargs):
         tuple: fig, ax reference to matplotlib figure and axis objects
     """
     import matplotlib.cm as _cm
+
     from ..magnets._polygon2D import PolyMagnet
 
     show_magnets = kwargs.pop("show_magnets", True)
@@ -184,9 +184,8 @@ def plot_2D_contour(point_array, field, **kwargs):
 
     if plot_type.lower() == "contour":
         cmap = kwargs.pop("cmap", "viridis")
-        vector_plot = kwargs.pop("vector_plot", False)
         vector_color = kwargs.pop("vector_color", "w")
-        NQ = kwargs.pop("vector_arrows", 11)
+        NQ = kwargs.pop("num_arrows", None)
 
         if field_component == "x":
             field_chosen = field.x
@@ -229,7 +228,7 @@ def plot_2D_contour(point_array, field, **kwargs):
             CB = _plt.colorbar(CS)
 
         # Draw field vectors
-        if vector_plot:
+        if NQ is not None:
             _vector_plot2(point_array, field, NQ, vector_color)
 
     elif plot_type.lower() == "streamplot":
@@ -313,7 +312,7 @@ def _num_patch_2D():
     Returns:
         tuple: (list, list) lists of patch and arrow objects
     """
-    from ..magnets._magnet2D import Magnet2D, Rectangle, Circle
+    from ..magnets._magnet2D import Circle, Magnet2D, Rectangle
 
     patch_array = []
     for magnet in Magnet2D.instances:
@@ -536,9 +535,8 @@ def plot_3D_contour(points, field, plane, **kwargs):
 
     # Generate Contour Plot
     if plot_type.lower() == "contour":
-        vector_plot = kwargs.pop("vector_plot", False)
         vector_color = kwargs.pop("vector_color", "w")
-        NQ = kwargs.pop("vector_arrows", 11)
+        NQ = kwargs.pop("num_arrows", None)
 
         cmap = kwargs.pop("cmap", "viridis")
         cmin = kwargs.pop("cmin", 0)
@@ -570,7 +568,7 @@ def plot_3D_contour(points, field, plane, **kwargs):
         else:
             CB = _plt.colorbar(CS)
 
-        if vector_plot:
+        if NQ is not None:
             B_2D = Field2(stream_x, stream_y, unit=field.unit)
             B_2D.n = field.n
             points_2D = Point_Array2(plot_x, plot_y, unit=points.unit)
@@ -647,13 +645,13 @@ def plot_sub_contour_3D(plot_x, plot_y, plot_B, **kwargs):
         tuple: fig, ax reference to matplotlib figure and axis objects
     """
     cmap = kwargs.pop("cmap", "seismic")
-    xlab = kwargs.pop("xlab", f"x (m)")
-    ylab = kwargs.pop("ylab", f"y (m)")
-    clab = kwargs.pop("clab", f"B (T)")
+    xlab = kwargs.pop("xlab", "x (m)")
+    ylab = kwargs.pop("ylab", "y (m)")
+    clab = kwargs.pop("clab", "B (T)")
 
-    axis_scale = kwargs.pop("axis_scale", "equal")
+    # axis_scale = kwargs.pop("axis_scale", "equal")
 
-    SAVE = kwargs.pop("save_fig", False)
+    # SAVE = kwargs.pop("save_fig", False)
 
     cmin = kwargs.pop("cmin", -0.5)
     cmax = kwargs.pop("cmax", 0.5)
@@ -737,7 +735,7 @@ def contour_plot_cylinder(magnet, **kwargs):
     Br, Bz = magnet._calcB_cyl(rho, z)
     Bn = _np.sqrt(Bz ** 2 + Br ** 2)
 
-    xlab = f"r (m)"
+    xlab = "r (m)"
     ylab = "z (m)"
 
     # plot_B = Bn
