@@ -10,21 +10,13 @@ Unlike the plot2D module, here plotly is used as the backend.
 TODO:
     * Update __str__ and __repr__ for polyhedra
 """
-from ..magnets._magnet_base import Registry
-from ..magnets import *
-from ..utils import grid3D, slice3D, get_field_3D
-from ..utils.global_const import PI, MAG_TOL
 import numpy as _np
 import plotly.graph_objects as _go
 
-
-__all__ = [
-    "plot_magnet",
-    "slice_plot",
-    "slice_quickplot",
-    "volume_plot",
-    "volume_quickplot",
-]
+from ..magnets import Cylinder, Magnet3D, Mesh, Prism, Sphere
+from ..magnets._magnet_base import Registry
+from ..utils import Quaternion, get_field_3D, grid3D, slice3D
+from ..utils.global_const import MAG_TOL, PI
 
 
 class Polyhedron(Registry):
@@ -110,8 +102,7 @@ class Graphic_Cuboid(Polyhedron):
                         self.gamma_rad,
                     ]
                 )
-            )
-            > Polyhedron.tol
+            ) > Polyhedron.tol
         ):
 
             # _, reverse_rotation = self._generate_rotation_quaternions()
@@ -376,11 +367,11 @@ class Graphic_Mesh(Polyhedron):
         vertices, ixr = _np.unique(
             self.mesh_vectors.reshape(p * q, r), return_inverse=True, axis=0
         )
-        I = _np.take(ixr, [3 * k for k in range(p)])
-        J = _np.take(ixr, [3 * k + 1 for k in range(p)])
-        K = _np.take(ixr, [3 * k + 2 for k in range(p)])
+        _I = _np.take(ixr, [3 * k for k in range(p)])
+        _J = _np.take(ixr, [3 * k + 1 for k in range(p)])
+        _K = _np.take(ixr, [3 * k + 2 for k in range(p)])
         x, y, z = vertices.T
-        trace = _go.Mesh3d(x=x, y=y, z=z, i=I, j=J, k=K, color=self.color)
+        trace = _go.Mesh3d(x=x, y=y, z=z, i=_I, j=_J, k=_K, color=self.color)
 
         # optional parameters to make it look nicer
         trace.update(
@@ -665,13 +656,11 @@ def slice_plot(data_dict, **kwargs):
     opacity = kwargs.pop("opacity", 0.8)
     magnet_opacity = kwargs.pop("magnet_opacity", 1.0)
     cone_opacity = kwargs.pop("cone_opacity", 1.0)
-    # planes = kwargs.pop("planes", ["xy", "xz", "yz"])
 
     cmin = kwargs.pop("cmin", 0)
     cmax = kwargs.pop("cmax", 0.5)
     colorscale = kwargs.pop("colorscale", "viridis")
     num_arrows = kwargs.pop("num_arrows", None)
-    # vector_plot = kwargs.pop("vector_plot", True)
 
     data_objects = []
 
@@ -700,11 +689,10 @@ def slice_plot(data_dict, **kwargs):
 
             NA = num_points // num_arrows
 
-            if NA < 1:
-                NA = 1
-            data_objects.append(
-                _draw_cones(points, field, NA=NA, cone_opacity=cone_opacity)
-            )
+            if NA > 1:
+                data_objects.append(
+                    _draw_cones(points, field, NA=NA, cone_opacity=cone_opacity)
+                )
 
     fig = _go.Figure(data=data_objects)
 
@@ -825,7 +813,7 @@ def volume_plot(points, field, **kwargs):
 
     reset_polyhedra()
 
-    opacity = kwargs.pop("opacity", 1)
+    opacity = kwargs.pop("opacity", 0.3)
     opacityscale = kwargs.pop("opacityscale", None)
     magnet_opacity = kwargs.pop("magnet_opacity", 1.0)
     cone_opacity = kwargs.pop("cone_opacity", 1.0)
@@ -934,4 +922,4 @@ def volume_quickplot(**kwargs):
     fig, data_objects = volume_plot(points, field, num_points=num_points, **kwargs)
     cache = {"points": points, "field": field}
 
-    return fig, cache, data_objects
\ No newline at end of file
+    return fig, cache, data_objects
